function [  ] = ThermocoupleAndVoltageMeasurements_ICT( inputAddress )

%
% This example uses the MATLAB Instrument Toolbox to control an Agilent 
% 3497x Data Acquisition Unit. 
%
% Description:
% Configure the 3497x Data Acquisition unit to gather temperature and DC voltage 
% measurements. The acquisition is started by a software trigger.  This example 
% measures channels 1-10 for type J thermocouple temperatures in Celcius and 
% channels 11-20 for DC voltage.  
%
% The example also demonstrates the use of Command Expert's MATLAB export code
% feature. The following code, minus the data logic, was generated from
% Command Expert. 
% 
% Running the Example:
%   1. In MATLAB, change the Current Folder directory to the location 
%   of this ThermocoupleAndVoltageMeasurements.m file. 
%   2.  Ensure that a valid multiplexer card is installed(see details
%   below).
%   3. In the MATLAB Command Window, call the function
%   ThermocoupleAndVoltageMeasurements_ICT with a valid instrument address.  
%   An example includes:
%
%   ThermocoupleAndVoltageMeasurements_ICT('GPIB0::6::INSTR');
%   
%
% Restrictions and Requirements:
% This example was written for an Agilent 34970A or 34972A Data Acquisition Unit.   
%
%Instructions for setting up the Multiplexer Card
%   1.  This example uses a 20 channel multiplexer card (model 34901A).
%   2.  Channels 1-10 are reserved for using type J thermocouple measurements, while Channels 11-20 
%       are used for DC voltage measurements.
%   3.  This example requires the card be placed into the first slot.  
%
% You have a royalty-free right to use, modify, reproduce and distribute
% this example program (and/or any modified version) in any way you find
% useful, provided you agree that Agilent Technologies has no warranty,
% obligations, or liability for any example programs.
%

v3497x = visa('agilent', inputAddress);
v3497x.InputBufferSize = 8388608;
v3497x.ByteOrder = 'littleEndian';


fopen(v3497x);

% Reset and clear the instrument
fprintf(v3497x, '*RST');
fprintf(v3497x, '*CLS');

% Setup channels 101 thru 110 to measure temperature (C) with type J thermocouples
fprintf(v3497x, sprintf(':CONF:TEMP %s,%s,(%s)', 'TCouple', 'J', '@101:110'));
fprintf(v3497x, sprintf(':UNIT:TEMP %s,(%s)', 'C', '@101:110'));
fprintf(v3497x, sprintf(':TEMP:TRAN:TC:RJUN:TYPE %s,(%s)', 'INTernal', '@101:110'));

% Setup channels 111 thru 120 to read voltage on the 10V range with 5.5 digit resolution
fprintf(v3497x, sprintf(':CONF:VOLT:DC %f,(%s)', 10.0, '@111:120'));
fprintf(v3497x, sprintf(':VOLT:DC:NPLC %f,(%s)', 1.0, '@111:120'));

% Scan Channels 101 thru 120
fprintf(v3497x, sprintf(':ROUT:SCAN (%s)', '@101:120'));
fprintf(v3497x, sprintf(':TRIG:COUN %d', 1));
fprintf(v3497x, sprintf(':TRIG:SOUR %s', 'TIMer'));

% Start trigger
fprintf(v3497x, ':INIT');
fprintf(v3497x, sprintf(':FORM:READ:CHAN %d', 0));

% Wait for scan to complete
fprintf(1,'Please wait 10 seconds for the measurement to complete.\n');
pause(10);

% Retrieve 10 Channels of thermo data
thermo = query(v3497x, sprintf(':DATA:REM? %d', 10));

% Retrieve 10 channels of voltage data
voltage = query(v3497x, sprintf(':DATA:REM? %d', 10));

% Close connection 
fclose(v3497x);
delete(v3497x);
clear v3497x;

% Convert and print out thermo and voltage values
fprintf(1,'Thermo Readings (C) from Channels 1-10:\n');
t = strread(thermo,'%s','delimiter',',')

fprintf(1,'Voltage Readings (V) from Channels 11-20:\n');
v = strread(voltage,'%s','delimiter',',')

end




