function [  ] = MultisetMeasurement_ICT( inputAddress, channelSource, expectedFrequency,gateTime,triggerDelay)

%
% This example uses the Instrument Control Toolbox to control an Agilent 532xx Frequency Counter.
%
% Description:
% Configures the 532xx frequency counter to measure 10 frequency samples on 
% channel 1.  The measurement is started by an external trigger.  The counter 
% detects an external trigger, delays one second, takes 5 frequency measurements, 
% receives a second external trigger, delays one second, and then completes the 
% remaining 5 measurements.     
%
% The example demonstrates the use of Command Expert's  MATLAB export code
% feature. The following code, minus the plotting logic, was generated from
% Command Expert. 
% 
% Running the Example:
%   1. In MATLAB, change the current folder directory to the location 
%   of this MultisetMeasurement_ICT.m file.  
%   2. In the MATLAB command window, call the function
%   MultisetMeasurement_ICT() with a valid instrument address, channel source, expected frequency, 
%   gate time, and trigger delay.  An example that connects to channel1 with an
%   expected frequency of 1000 hertz, a gate time of .001 seconds, a
%   trigger delay of 1 second, and to a GPIB connection would look like:
%
%   MultisetMeasurement_ICT('GPIB0::12::INSTR', '@1',1000,.001,1);
%   
% Restrictions and Requirements:
% 1. Place an appropriate AC input source into the selected channel of the counter.
% 2. Add another TTL level source into the rear EXT channel that will trigger the measurement. 
% 3. Change the expected frequency, gatetime, and/or channel input number to match your source.  
% 4. Call this function.
%
% Requirements
% This example was written for an Agilent 532xx frequency counter.  It was tested on firmware version 1.10.   
%
% You have a royalty-free right to use, modify, reproduce and distribute
% this example program (and/or any modified version) in any way you find
% useful, provided you agree that Agilent Technologies has no warranty,
% obligations, or liability for any example programs.
%

v532xx = visa('agilent', inputAddress);
v532xx.InputBufferSize = 8388608;
v532xx.ByteOrder = 'littleEndian';
v532xx.Timeout = 5;
fopen(v532xx);
fprintf(v532xx, '*RST');
fprintf(v532xx, '*CLS');

fprintf('Please wait a few seconds for the frequency measurements to complete\n');

fprintf(v532xx, sprintf(':CONFigure:SCALar:VOLTage:FREQuency %f,%f,(%s)', expectedFrequency, gateTime, channelSource));
fprintf(v532xx, sprintf(':TRIGger:SEQuence:SOURce %s', 'EXTernal'));
fprintf(v532xx, sprintf(':TRIGger:SEQuence:SLOPe %s', 'POSitive'));
fprintf(v532xx, sprintf(':TRIGger:SEQuence:COUNt %d', 2));
fprintf(v532xx, sprintf(':TRIGger:DELay %f', triggerDelay));
fprintf(v532xx, sprintf(':SAMPle:COUNt %d', 5));
C = textscan(query(v532xx, ':READ?'), '%f', 'Delimiter', ',');
frequencyData = C{1};

fclose(v532xx);
delete(v532xx);
clear v532xx;

%Plot Frequency Values
plot(1:1:10,frequencyData);
title('Frequency Capture Plot');
ylabel('Frequency (Hz)');
xlabel('Sample Point');
end

