function [  ] = VoltageSweep_ICT( inputAddress,voltageList, voltageInterval,outputSource )

% Description:
% Performs a voltage sweep and measures the current drawn at each voltage 
% point. The example graphs the current drawn.  
%
% The example demonstrates the use of Command Expert's  MATLAB export code
% feature. The following code, minus the plotting/looping logic, was generated from
% Command Expert. 
% 
% Running the Example:
%   1. In MATLAB, change the current folder directory to the location 
%   of this VoltageSweep_ICT.m file.  
%   2. In the MATLAB Command Window, call the function VoltageSweep_ICT
%   with a valid GPIB or Serial instrument address, intervalTime in seconds, 
%   and outputSource (PV6/P25V/N25V). 
%
%   A GPIB interface example that cycles the voltages from 0V to 3V in 
%   .5V intervals on the 6V output source, holding each voltage level 
%   2 seconds would be called with:
%    
%   voltageList = 0:.5:3;
%   VoltageSweep_ICT('GPIB::19::INSTR',voltageList, 2, 'P6V');
%   
%   3. If the N25V source is used the voltage list can contain only negative
%    values.
%   4. If the RS-232 connection is used, uncomment the SYSTem:Remote
%   command in the code below. 
%
% Restrictions and Requirements:
% This example was written for the Agilent E3631A Triple Output DC Power 
% Supply, and was tested with firmware version 1.1-5.0-1.0. 
%
% You have a royalty-free right to use, modify, reproduce and distribute
% this example program (and/or any modified version) in any way you find
% useful, provided you agree that Agilent Technologies has no warranty,
% obligations, or liability for any example programs.
%


E3631 = visa('agilent', inputAddress);
E3631.InputBufferSize = 8388608;
E3631.ByteOrder = 'littleEndian';
fopen(E3631);
fprintf('Connected to PSU at address %s\n',inputAddress);

% For RS-232 connections Only, uncomment the following command
% fprintf(E3631, ':SYSTem:REMote');

%Enable the PSU source
fprintf(E3631, sprintf(':OUTPut:STATe %d', 1));

%Cycle thru voltage list, and grab measured current and voltage values.
i = 1;
while(i<=max(size(voltageList)))
 fprintf('PSU Output %d (V) on Source %s\n',voltageList(i),outputSource);
 fprintf(E3631, sprintf(':APPLy %s,%f', outputSource, voltageList(i)));
 
 %Wait and allow PSU to output voltage for the defined interval time.
 pause(voltageInterval);
 
 measuredCurrent(i) = str2double(query(E3631, sprintf(':MEASure:CURRent:DC? %s',outputSource ))); %#ok<AGROW>
 measuredVoltage(i) = str2double(query(E3631, sprintf(':MEASure:VOLTage:DC? %s', outputSource))); %#ok<AGROW>
 
 i = i + 1;
end

%Disable the PSU source
fprintf(E3631, sprintf(':OUTPut:STATe %d', 1));

fclose(E3631);
delete(E3631);
clear E3631;

%Plot the Current Drawn at each Voltage Point
plot(measuredVoltage, measuredCurrent)
title('Current Drawn over Voltage Sweep ');
xlabel('Voltage (V)');
ylabel('Current (A)');


end



