function [  ] = WaveformDownload_ICT( inputAddress,channel )

% Description:
% Acquires an autoscaled waveform from a selectable channel of an Agilent InfiniiVision 
% 3000 Series oscilloscope.   
%
% The example demonstrates the use of Command Expert's  MATLAB export code
% feature. The following code, minus the plotting logic, was generated from
% Command Expert. 
% 
% Running the Example:
%   1. In MATLAB, change the current folder directory to the location 
%   of this WaveformDownload_ICT.m file.  
%   2. In the MATLAB Command Window, call the function WaveformDownload_ICT
%   with a valid GPIB,USB,or LAN VISA address, and channel number (1-4).
%   A GPIB interface connected instrument that captures the first channel could be
%   called with:
%
%   WaveformDownload_ICT('GPIB::22::INSTR','CHANNEL1');
%   
% Viewing the Plot
% This sequence grabs 1000 points to represent the waveform.  It 
%captures the data in the BYTE format which needs to be translated to
%represent the y-axis by using the preamble information. Time data (x-axis) can be
%generated also by using the preamble's x-origin and x-increment information. 

% Restrictions and Requirements:
% This example was written for oscilloscopes in the Agilent Infiniium  
%3000 Series. This was tested with firmware version 01.10.20111042700.
%
% You have a royalty-free right to use, modify, reproduce and distribute
% this example program (and/or any modified version) in any way you find
% useful, provided you agree that Agilent Technologies has no warranty,
% obligations, or liability for any example programs.
%


InfiniiVision = visa('agilent', inputAddress);
InfiniiVision.InputBufferSize = 8388608;
InfiniiVision.ByteOrder = 'littleEndian';
fopen(InfiniiVision);

fprintf(InfiniiVision, '*RST');
fprintf(InfiniiVision, '*CLS');
fprintf(InfiniiVision, ':AUToscale');
fprintf(InfiniiVision, ':DIGitize');
% Send 1000 points to represent the waveform.
fprintf(InfiniiVision, sprintf(':WAVeform:POINts %s', 'NORMal'));
fprintf(InfiniiVision, sprintf(':WAVeform:POINts %d', 1000));
fprintf(InfiniiVision, sprintf(':WAVeform:SOURce %s', channel));
fprintf(InfiniiVision, sprintf(':WAVeform:UNSigned %d', 1));
fprintf(InfiniiVision, sprintf(':WAVeform:BYTeorder %s', 'LSBF'));
fprintf(InfiniiVision, sprintf(':WAVeform:FORMat %s', 'BYTE'));
fprintf(InfiniiVision, ':WAVeform:DATA?');
waveformBYTEData = binblockread(InfiniiVision, 'uint8');

% X-Axis preamble information is used create the time based x-axis values. 
xincrement = str2double(query(InfiniiVision, ':WAVeform:XINCrement?'));
xorigin = str2double(query(InfiniiVision, ':WAVeform:XORigin?'));
% Y-axis preamble information converts the BYTE format to actual voltage values.  
%The BYTE format is used to increase the efficiency of waveform data transfer.
yincrement = str2double(query(InfiniiVision, ':WAVeform:YINCrement?'));
yorigin = str2double(query(InfiniiVision, ':WAVeform:YORigin?'));
yreference = sscanf(query(InfiniiVision, ':WAVeform:YREFerence?'), '%d');

waveformBYTEData = double(waveformBYTEData);
yAxisVoltage = size(1, max(size(waveformBYTEData)));
yAxisVoltage = double(yAxisVoltage);

fclose(InfiniiVision);
delete(InfiniiVision);
clear InfiniiVision;

%Generate Y-Axis Time Values
i = 1;
while(i <= max(size(waveformBYTEData)))
    yAxisVoltage(i) = waveformBYTEData(i) - yreference;
    yAxisVoltage(i) = yAxisVoltage(i)*yincrement+yorigin; 
    i = i + 1;   
end

%Generate X-Axis Time Values
xAxisTime(1) = xorigin;
i = 2;
while(i <= max(size(waveformBYTEData)))
    xAxisTime(i) = xAxisTime(i-1) + xincrement;        %#ok<AGROW>
    i = i + 1;
end

plot(xAxisTime, yAxisVoltage)
title('Waveform Download');
xlabel('Time(s)');
ylabel('Voltage (V)');


end



