% Description:
% Performs a voltage sweep and measures the current drawn at each voltage 
% point. This example steps from 0V to 3V in .5V intervals.  Each 
% interval is held for 2 seconds. These values can be changed by altering the 
% below variables.  This example graphs the current drawn.  

% The example demonstrates using the agRunSequence
% function to run the Command Expert sequence file
% E3631_PowerSupply_VoltageSweep.iseq that is included in 
% the same directory as this file.
% 
% Running the Example:
%   1. In the MATLAB Command Window, assign the variable named 'address' a
%   string value that is the instrument address of an Agilent E3631A Power  
%   Supply. For example, you would type the following, replacing
%   'abcdefg' with your instrument address.
%
%   address = 'abcdefg';
%
%   A commom GPIB instrument address is GPIB0::19::INSTR.
%   See the help for agRunSequence for additional instrument address details.
%
%   2. Open the E3631_PowerSupply_VoltageSweep sequence and 
%	change the wait statement interval if needed.  This will alter how long the 
%   the power supply holds each voltage point until it switches to the next.
%   3. Edit the voltage list with values to sweep.
%   4. Change variable outputSource to the P6V, P25V, or N25V source. If the
%   source is N25V then the voltageList will need negative voltage values. 
%   5. For RS-232 connections only, open the E3631_PowerSupply_VoltageSweep.iseq file and 
%   uncomment the SYSTem:Remote command.
%   6. With this file open in the MATLAB editor, click the Run button.
%
% Restrictions and Requirements:
% This example was written for the Agilent E3631A Triple Output DC Power 
% Supply, and was tested with firmware version 1.1-5.0-1.0. 
%
% You have a royalty-free right to use, modify, reproduce and distribute
% this example program (and/or any modified version) in any way you find
% useful, provided you agree that Agilent Technologies has no warranty,
% obligations, or liability for any example programs.
%
% See also agRunSequence.

%Change Variables
outputSource = 'P6V';   % Values can be: P6V, P25V, or N25V. 
intervalTime = 2;       % 2 seconds
voltageList = 0:.5:3;   % Cycle voltages from 0V to 3V in .5V increments.


%Cycle thru voltage list, and grab measured current and voltage values.
i = 1;
while(i<=max(size(voltageList)))
    
 fprintf('PSU Output %d (V) on Source %s\n',voltageList(i),outputSource);
 currentVoltage = voltageList(i);
 [tempCurrent,tempVoltage] =   agRunSequence('E3631_PowerSupply_VoltageSweep',address,currentVoltage,outputSource);
 
 measuredVoltage(i) = tempVoltage;  %#ok<SAGROW>
 measuredCurrent(i) = tempCurrent; %#ok<SAGROW>
 
 i = i + 1;
end


plot(measuredVoltage, measuredCurrent)
title('Current Drawn over Voltage Sweep ');
xlabel('Voltage (V)');
ylabel('Current (A)');



