﻿/* 
 * This example uses the SCPI.NET driver to control an Agilent 3497x Data Acquisition Unit.
 *
 * Description
 * Configure the 3497x Data Acquisition unit to gather temperature and DC voltage measurements. 
 * The acquisition is started by a software trigger.  This example measures channels 1-10 for 
 * type J thermocouple temperatures in Celcius and channels 11-20 for DC voltage.  
 *
 *
 *Instructions for Running:
 * 1. Setup the multiplexer card for temperature and voltage measurements(see below). 
 * 2. Insert multiplexer card into the first slot.
 * 3. Update the instrument address in the connect statement.
 * 4. Run the sequence.
 *
 *Instructions for setting up the Multiplexer Card
 * 1. This example uses a 20 channel multiplexer card (model 34901A).
 * 2. Channels 1-10 are reserved for using type J thermocouple measurements, while Channels 11-20 
 *    are used for DC voltage measurements.
 * 3. This example requires the card be placed into the first slot.
 *
 * Requirements:
 * This example was written for an Agilent 34972A/34970A Data Acquistion Unit.  
 * 
 * Instructions for compiling
 * This example calls the SCPI.NET 3497x driver that is needed as a reference.  This file is downloaded when 
 * Command Expert installs the command set.  See Command Expert's Visual Studio help for additional information. 
 *   
 * You have a royalty-free right to use, modify, reproduce and distribute 
 * this example program (and/or any modified version) in any way you find useful,
 * provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Agilent.CommandExpert.ScpiNet.Ag3497x_1_13;

namespace ThermocoupleAndVoltageMeas
{
    class Program
    {
        static void Main(string[] args)
        {
            
            int points_num = 0;
            string thermoReadings = null;
            string voltageReadings = null;
            Ag3497x v3497x = new Ag3497x("ToBeFilled");

            Console.Out.WriteLine("Wait 10 seconds for the measurement to complete\n");
            
            // Reset and clear the instrument
            v3497x.SCPI.RST.Command();
            v3497x.SCPI.CLS.Command();

            // Setup channels 101 thru 110 to measure temperature (C) with type J thermocouples
            v3497x.SCPI.CONFigure.TEMPerature.Command("TCouple", "J", null, null, "@101:110");
            v3497x.SCPI.UNIT.TEMPerature.Command("C", "@101:110");
            v3497x.SCPI.SENSe.TEMPerature.TRANsducer.TCouple.RJUNction.TYPE.Command("INTernal", "@101:110");

            // Setup channels 111 thru 120 to read voltage on the 10V range with 5.5 digit resolution
            v3497x.SCPI.CONFigure.VOLTage.DC.Command(10, null, "@111:120");
            v3497x.SCPI.SENSe.VOLTage.DC.NPLC.Command(1, "@111:120");

            // Scan Channels 101 thru 120
            v3497x.SCPI.ROUTe.SCAN.Command("@101:120");
            v3497x.SCPI.TRIGger.COUNt.Command(1);
            v3497x.SCPI.TRIGger.SOURce.Command("TIMer");

            // Start trigger
            v3497x.SCPI.INITiate.Command();
            v3497x.SCPI.FORMat.READing.CHANnel.Command(false);

            // Wait for scan to complete
            System.Threading.Thread.Sleep(10000);
            v3497x.SCPI.DATA.POINts.Query(out points_num);

            // Retrieve 10 Channels of thermo data
            v3497x.SCPI.DATA.REMove.QueryReadingsPlusUnits(10, out thermoReadings);

            // Retrieve 10 channels of voltage data
            v3497x.SCPI.DATA.REMove.QueryReadingsPlusUnits(10, out voltageReadings);

            //split comma seperated array
            string[] tArray = thermoReadings.Split(',');
            string[] vArray = voltageReadings.Split(',');


            //print out measured thermo values
            for (int i = 0; i < 10; i++)
            {
                Console.Out.WriteLine("Channel " + (i + 1) + ": " + tArray[i] + " (C)");
            }

            //print out measured voltage values
            for ( int i = 0; i < 10; i++)
            {
                Console.Out.WriteLine("Channel " + (i + 11) + ": " + vArray[i] + " (V)");
            }

            //Stall Console
            Console.WriteLine("\nPress enter to continue . . .");
            Console.ReadLine();
        }
    }
}
