﻿' 
' This example uses the SCPI.NET driver to control an Agilent 3497x Data Acquisition Unit.
'
' Description
' Configure the 3497x Data Acquisition unit to gather temperature and DC voltage measurements. 
' The acquisition is started by a software trigger.  This example measures channels 1-10 for 
' type J thermocouple temperatures in Celcius and channels 11-20 for DC voltage.  
'
'
' Instructions for Running:
' 1. Setup the multiplexer card for temperature and voltage measurements(see below). 
' 2. Insert multiplexer card into the first slot.
' 3. Update the instrument address in the connect statement.
' 4. Run the sequence.
'
' Instructions for setting up the Multiplexer Card
' 1. This example uses a 20 channel multiplexer card (model 34901A).
' 2. Channels 1-10 are reserved for using type J thermocouple measurements, while Channels 11-20 
'    are used for DC voltage measurements.
' 3. This example requires the card be placed into the first slot.
'
' Requirements:
' This example was written for an Agilent 34972A/34970A Data Acquistion Unit.  
' 
' Instructions for compiling
' This example calls the SCPI.NET 3497x driver that is needed as a reference.  This file is downloaded when 
' Command Expert installs the command set.  See Command Expert's Visual Studio help for additional information. 
'   
' You have a royalty-free right to use, modify, reproduce and distribute 
' this example program (and/or any modified version) in any way you find useful,
' provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
'



Imports Agilent.CommandExpert.ScpiNet.Ag3497x_1_13

Module Module1

    Sub Main()
        Dim thermoReadings As String = Nothing
        Dim voltageReadings As String = Nothing
        Dim v3497x As Ag3497x = New Ag3497x("ToBeFilled")

        Console.Out.WriteLine("Wait 10 seconds for the measurement to complete.")

        'Reset and clear the instrument
        v3497x.SCPI.RST.Command()
        v3497x.SCPI.CLS.Command()

        'Setup channels 101 thru 110 to measure temperature (C) with type J thermocouples
        v3497x.SCPI.CONFigure.TEMPerature.Command("TCouple", "J", DBNull.Value, DBNull.Value, "@101:110")
        v3497x.SCPI.UNIT.TEMPerature.Command("C", "@101:110")
        v3497x.SCPI.SENSe.TEMPerature.TRANsducer.TCouple.RJUNction.TYPE.Command("INTernal", "@101:110")

        'Setup channels 111 thru 120 to read voltage on the 10V range with 5.5 digit resolution
        v3497x.SCPI.CONFigure.VOLTage.DC.Command(10, DBNull.Value, "@111:120")
        v3497x.SCPI.SENSe.VOLTage.DC.NPLC.Command(1, "@111:120")

        'Scan Channels 101 thru 120
        v3497x.SCPI.ROUTe.SCAN.Command("@101:120")
        v3497x.SCPI.TRIGger.COUNt.Command(1)
        v3497x.SCPI.TRIGger.SOURce.Command("TIMer")

        'Start trigger
        v3497x.SCPI.INITiate.Command()
        v3497x.SCPI.FORMat.READing.CHANnel.Command(False)

        'Wait for scan to complete
        System.Threading.Thread.Sleep(10000)

        'Retrieve 10 Channels of thermo data
        v3497x.SCPI.DATA.REMove.QueryReadingsPlusUnits(10, thermoReadings)

        'Retrieve 10 channels of voltage data
        v3497x.SCPI.DATA.REMove.QueryReadingsPlusUnits(10, voltageReadings)

        'Split comma seperated strings
        Dim tArray() As String = thermoReadings.Split(",")
        Dim vArray() As String = voltageReadings.Split(",")

        'Print out Measured Values
        Dim i As Integer

        For i = 0 To 9
            Console.Out.WriteLine("Channel {0}: {1} (C)", (i + 1), tArray(i))
        Next i

        For i = 0 To 9
            Console.Out.WriteLine("Channel {0}: {1} (V)", (i + 11), vArray(i))
        Next i

        'Stall console
        Console.WriteLine("Hit enter key to exit" + vbNewLine)
        Console.ReadLine()

    End Sub

End Module
