/* 
 * This example uses the VISA Library to control an Agilent 3497x Data Acquisition Unit.
 *
* Description
 * Configure the 3497x Data Acquisition unit to gather temperature and DC voltage measurements. 
 * The acquisition is started by a software trigger.  This example measures channels 1-10 for 
 * type J thermocouple temperatures in Celcius and channels 11-20 for DC voltage.  
 *
 *Instructions for Running:
 * 1. Setup the multiplexer card for temperature and voltage measurements(see below). 
 * 2. Insert multiplexer card into the first slot.
 * 3. Update the instrument address in the connect statement.
 * 4. Run the sequence.
 *
 *Instructions for setting up the Multiplexer Card
 * 1. This example uses a 20 channel multiplexer card (model 34901A).
 * 2. Channels 1-10 are reserved for using type J thermocouple measurements, while Channels 11-20 
 *    are used for DC voltage measurements.
 * 3. This example requires the card be placed into first slot.
 *
 * Requirements:
 * This example was written for an Agilent 34972A/34970A Data Acquistion Unit.  
 * 
 * Instructions for compiling.
 *   This example requires including visa.h and visa32.lib found in the IVI Foundation folder. 
 * These files are installed with Agilent IO Libraries. The default pathway has already been set in the project's 
 * linker and include settings. 
 *   
 * You have a royalty-free right to use, modify, reproduce and distribute 
 * this example program (and/or any modified version) in any way you find useful,
 * provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
 */

#include "stdafx.h"
#include "visa.h"


int _tmain(int argc, _TCHAR* argv[])
{

ViSession rm;
	viOpenDefaultRM(&rm);
	ViSession v3497x;
	ViUInt16 io_prot;
	ViUInt16 intfType;
	ViString intfName[512];

	long points_num = 0;
	int readings_size = 10;
	char *thermoReadings[10];
	char *voltageReadings[10];

	//Allocate memory to pointer
	for(int i = 0; i < readings_size;i++)
	{
		thermoReadings[i] = new char[1000];
		voltageReadings[i] = new char[1000];
	}

	viOpen(rm, "GPIB0::6::INSTR", VI_NULL, VI_NULL, &v3497x);
	ViBoolean termDefaultv3497x = VI_FALSE;

	// Determine whether the termination character should be enabled by default.
	if((VI_SUCCESS == viGetAttribute(v3497x, VI_ATTR_RSRC_CLASS, intfName)) && (0 == strcmp("SOCKET", (ViString)intfName)))
		termDefaultv3497x = VI_TRUE;
	else if((VI_SUCCESS == viGetAttribute(v3497x, VI_ATTR_INTF_TYPE, &intfType)) && (intfType == VI_INTF_ASRL))
		termDefaultv3497x = VI_TRUE;

	viSetAttribute(v3497x, VI_ATTR_TERMCHAR_EN, termDefaultv3497x);

	// Reset and clear the instrument
	viPrintf(v3497x, "*RST\n");
	viPrintf(v3497x, "*CLS\n");

	// Setup channels 101 thru 110 to measure temperature (C) with type J thermocouples
	viPrintf(v3497x, ":CONFigure:TEMPerature %s,%s,(%s)\n", "TCouple", "J", "@101:110");
	viPrintf(v3497x, ":UNIT:TEMPerature %s,(%s)\n", "C", "@101:110");
	viPrintf(v3497x, ":SENSe:TEMPerature:TRANsducer:TCouple:RJUNction:TYPE %s,(%s)\n", "INTernal", "@101:110");

	// Setup channels 111 thru 120 to read voltage on the 10V range with 5.5 digit resolution
	viPrintf(v3497x, ":CONFigure:VOLTage:DC %@3lf,(%s)\n", 10.0, "@111:120");
	viPrintf(v3497x, ":SENSe:VOLTage:DC:NPLC %@3lf,(%s)\n", 1.0, "@111:120");

	// Scan Channels 101 thru 120
	viPrintf(v3497x, ":ROUTe:SCAN (%s)\n", "@101:120");
	viPrintf(v3497x, ":TRIGger:COUNt %@1d\n", 1);
	viPrintf(v3497x, ":TRIGger:SOURce %s\n", "TIMer");

	// Start trigger
	viPrintf(v3497x, ":INITiate\n");
	viPrintf(v3497x, ":FORMat:READing:CHANnel %@1d\n", 0);

	// Wait for scan to complete
	Sleep(10000);
	viQueryf(v3497x, ":DATA:POINts?\n", "%d", &points_num);
	
	// Retrieve 10 channels of thermocouple temperature data and print it out
	int i;
	for(i = 0; i < 10; i++)
	{
	   viQueryf(v3497x, ":DATA:REMove? %d\n", "%t", 1, thermoReadings[i]);
	   printf("Channel %d (V): %s",(i+1),thermoReadings[i]);
	}

	// Retrieve 10 channels of voltage data and print it out
	for(i = 0; i < 10; i++)
	{
	   viQueryf(v3497x, ":DATA:REMove? %d\n", "%t",1, voltageReadings[i]);
	   printf("Channel %d (C): %s",(i+11),voltageReadings[i]);
	}

	viClose(v3497x);
	viClose(rm);

	//Hang Console
	printf("\nPress enter to exit");
	getch();

	return 0;
	
}


