﻿/* 
 * Description
 * Configures the 532xx frequency counter to measure 10 frequency samples on channel 1.  
 * The measurement is started by an external trigger.  The counter detects an external trigger, 
 * delays one second, takes 5 frequency measurements, receives a second external trigger, 
 * delays one second, and then completes the remaining 5 measurements.  
 * 
 * Instructions for Running:
 * 1. Place an appropriate AC input source into the selected channel and then alter the 'channelSource' variable.
 *    The symbol @1 refers to channel1 while @2 refers to channel2.  
 * 2. Add another TTL level capable source into the rear EXT channel to trigger the measurement. 
 * 3. Change the expected frequency, gatetime, and/or trigger delay to match your source.  
 * 4. Update the first connect statement with a valid instrument address.
 * 5. Copy the "532xx_FrequencyCounter_MultisetMeasurement.iseq" file into the program's run directory. Ex: Debug\Bin 
 * 6. Run this program.  
 * 
 * Instructions for compiling
 * This example requires reference libraries to run a sequence. The sequence file "532xx_FrequencyCounter_MultisetMeasurement.iseq" must
 * also be in the program's run directory. Please see Command Expert's Visual Studio help for reference. 
 *    
 * Requirements:
 * This example was written for an Agilent 532xx frequency counter.  It was tested on firmware version 1.10.   
 * The external trigger source must receive a TTL level signal and the input channel must receive an AC signal. 
 * 
 * You have a royalty-free right to use, modify, reproduce and distribute 
 * this example program (and/or any modified version) in any way you find useful,
 * provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
 */ 

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Agilent.CommandExpert.DataModel.Sequence;
using Agilent.CommandExpert.SequenceExecution;

namespace MultisetRunSequence
{
    class Program
    {
        static void Main(string[] args)
        {
            double expectedFrequency = 1000;   //expected frequency is in hertz
            double gateTime = .001;           // gate time is in seconds
            string channelSource = "@1";     // @1 = Channel 1, @2 = Channel 2
            double triggerDelay = 1;        //trigger delay is in seconds
                                              
            double[] frequencyData = new double[10];  //By default this example gathers 10 frequency readings

            SequenceModel seq = new SequenceModel();
            seq.Load("532xx_FrequencyCounter_MultisetMeasurement.iseq");
            seq.SetInstrumentAddresses("To Be Filled");

            Console.WriteLine("Please wait a few seconds for the measurements to complete");
            object[] ret = seq.Play(expectedFrequency, gateTime, channelSource, triggerDelay);
            frequencyData = (double[])ret[0];

            //Print out the Frequency Values
            for (int i = 0; i < frequencyData.Length; i++)
            {
                Console.WriteLine("Frequence Sample " + (i + 1) + " reads: " + frequencyData[i] + " (Hz)");
            }

            //Wait for user input
            Console.WriteLine("Press enter to exit\n");
            Console.ReadLine();

        }
    }
}
