﻿/* 
 * This example uses the SCPI.NET driver to control an Agilent 532xx Frequency Counter.
 *
 * Description
 * Configures the 532xx frequency counter to measure 10 frequency samples on channel 1.  
 * The measurement is started by an external trigger.  The counter detects an external trigger, 
 * delays one second, takes 5 frequency measurements, receives a second external trigger, 
 * delays one second, and then completes the remaining 5 measurements.      
 *
 *Instructions for Running:
 * 1. Place an appropriate AC input source into either channel 1 or channel 2.  If you use channel 2 then alter the 'channelSource' variable.
 *    The symbol @1 refers to channel1 while @2 refers to channel2.  
 * 2. Add another TTL level source into the rear EXT channel that will trigger the measurement. 
 * 3. Change the expected frequency, gatetime, and/or trigger delay to match your source.  
 * 4. Update the first connect statement with a valid instrument address.  
 * 5. Run this program.  
 *
 * Instructions for compiling.
 *    This example calls the SCPI.NET 532xx driver that is needed as a reference.  This file is downloaded when 
 *  Command Expert installs this command set.  See Command Expert's Visual Studio help for additional information.     
 *    
 * Requirements:
 * This example was written for an Agilent 532xx frequency counter.  It was tested on firmware version 1.10.   
 * The external trigger source must receive a TTL level signal and the input source must receive an AC signal. 
 *
 * You have a royalty-free right to use, modify, reproduce and distribute 
 * this example program (and/or any modified version) in any way you find useful,
 * provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Agilent.CommandExpert.ScpiNet.Ag532xx_1_05;

namespace MultisetScpiDotNet
{
    class Program
    {
        static void Main(string[] args)
        {
            double expectedFrequency = 1000;   //expected frequency is in hertz
            double gateTime = .001;           // gate time is in seconds
            string channelSource = "@1";     // @1 = Channel 1, @2 = Channel 2
            double triggerDelay = 1;        //trigger delay is in seconds
            const int numFrequencyReadings = 10;

            double[] frequencyData = new double[numFrequencyReadings];  //By default this example gathers 10 frequency readings


            Ag532xx v532xx = new Ag532xx("To Be Filled");

            Console.WriteLine("Please wait a few seconds for the measurements to complete");
            v532xx.Transport.DefaultTimeout.Set(5000);
            v532xx.SCPI.RST.Command();
            v532xx.SCPI.CLS.Command();
            v532xx.SCPI.CONFigure.SCALar.VOLTage.FREQuency.Command(expectedFrequency, gateTime, channelSource);
            v532xx.SCPI.TRIGger.SEQuence.SOURce.Command("EXTernal");
            v532xx.SCPI.TRIGger.SEQuence.SLOPe.Command("POSitive");
            v532xx.SCPI.TRIGger.SEQuence.COUNt.Command(2);
            v532xx.SCPI.TRIGger.DELay.Command(triggerDelay);
            v532xx.SCPI.SAMPle.COUNt.Command(5);
            v532xx.SCPI.READ.QueryAsciiReal(out frequencyData);

            //Print out the Frequency Values
            for (int i = 0; i < numFrequencyReadings; i++)
            {
                Console.WriteLine("Frequence Sample " + (i + 1) + " reads: " + frequencyData[i]+" (Hz)");
            }

            //Wait for user input
            Console.WriteLine("Press enter to exit\n");
            Console.ReadLine();
        }
    }
}
