/* 
 * This example uses the VISA Library to control an Agilent 532xx Frequency Counter.
 *
 * Description
 * Configures the 532xx frequency counter to measure 10 frequency samples on channel 1.  
 * The measurement is started by an external trigger.  The counter detects an external trigger, 
 * delays one second, takes 5 frequency measurements, receives a second external trigger, 
 * delays one second, and then completes the remaining 5 measurements.      
 * 
 *Instructions for Running:
 * 1. Place an appropriate input source into the selected channel and then alter the 'channelSource' variable.
 *    The symbol @1 refers to channel1 while @2 refers to channel2.  
 * 2. Add another source into the rear EXT channel that will trigger the measurement. 
 * 3. Change the expected frequency, gatetime, and/or trigger delay to match your source.  
 * 4. Update the first connect statement with a valid instrument address.  
 * 5. Run this program. 
 *
 * Instructions for compiling.
 * This example calls the Agilent VISA library (visa32.lib) that is needed as a reference with visa.h.  
 * Please see the IO Library VISA API help file for file locations.  The common paths have been added to this project.  
 *    
 * Requirements
 * This example was written for an Agilent 532xx frequency counter.  It was tested on firmware version 1.10.   
 * The external trigger source must receive a TTL level signal and the input channel must receive an AC signal. 
 *
 * You have a royalty-free right to use, modify, reproduce and distribute 
 * this example program (and/or any modified version) in any way you find useful,
 * provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
 */

#include "stdafx.h"
#include "visa.h"

int _tmain(int argc, _TCHAR* argv[])
{
	ViSession rm;
	viOpenDefaultRM(&rm);
	ViSession v532xx;

	double expectedFrequency = 1000;    //expected frequency is in hertz
    double gateTime = .001;            // gate time is in seconds
    char  channelSource[5] = "@1";    // @1 = Channel 1, @2 = Channel 2
    float triggerDelay = 1;          //Trigger delay is in seconds. Long trigger delays require a longer default
                                       
    const int numFrequencyReadings = 10;
    double frequencyData[10];      //By default this example gathers 10 frequency readings

	viOpen(rm, "To Be Filled", VI_NULL, VI_NULL, &v532xx);

	printf("Please wait a few seconds for the measurements to complete\n");
	viSetAttribute(v532xx,VI_ATTR_TMO_VALUE,5000);
	viPrintf(v532xx, "*RST\n");
	viPrintf(v532xx, "*CLS\n");
	viPrintf(v532xx, ":CONFigure:SCALar:VOLTage:FREQuency %@3lf,%@3lf,(%s)\n", expectedFrequency, gateTime, channelSource);
	viPrintf(v532xx, ":TRIGger:SEQuence:SOURce %s\n", "EXTernal");
	viPrintf(v532xx, ":TRIGger:SEQuence:SLOPe %s\n", "POSitive");
	viPrintf(v532xx, ":TRIGger:SEQuence:COUNt %@1d\n", 2);
	viPrintf(v532xx, ":TRIGger:DELay %@3lf\n", triggerDelay);
	viPrintf(v532xx, ":SAMPle:COUNt %@1d\n", 5);
	viQueryf(v532xx, ":READ?\n", "%,10lf", frequencyData);
	viClose(v532xx);
	viClose(rm);

	for(int i = 0; i < numFrequencyReadings;i++)
	{
		printf("Frequency sample %d reads: %f (Hz)\n",(i+1),frequencyData[i]);
	}

	//Wait for user input
	printf("Press enter to exit");
	getch();

	return 0;
}

