﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Agilent.CommandExpert.DataModel.Sequence;
using Agilent.CommandExpert.SequenceExecution;

/*
* Description
* Performs a voltage sweep and measures the current drawn at each voltage point. This example sweeps
* the 6V Source (P6V) 0V to 3V in .5V intervals.  Each voltage level is held for 2 seconds before switching to 
* next.  
* 
* Instructions for Running:
* 1. Copy the E3631_PowerSupply_VoltageSweep.iseq run sequence file into the program's run directory.
* 2. Update the instrument address in the "To Be Filled" connect statement.
* 3. Switch the outputSource variable to the selected source.
*      P6V  - Refers to the 6V Source
*      P25V - Refers to positive 25V Source
*      N25V - Referes to negative 25V Source
* 4. Adjust the voltageList array with voltage values within the selected source's range.  For example, the P6V 
*    is limited to 6V while the N25V source accepts negative voltage values greater than or equal to -25V.  
* 5. Open the E3631_PowerSupply_VoltageSweep.iseq file and change the wait statement to increase or decrease the 
*    time each voltage point is held before switching to the next.  
* 6. For RS-232 connections only, uncomment the "SYSTem:Remote" command in the sequence file.
* 7. Run this program.
* 
* Viewing the Data
* This console application lacks a graphing component for simplicity.  Instead, each voltage point measures the current 
* drawn.  This example prints these values out.  
*    
* Requirements:
* This example was written for the Agilent E3631A Triple Output DC Power Supply, and was tested with firmware version 1.1-5.0-1.0. 
*
* You have a royalty-free right to use, modify, reproduce and distribute 
* this example program (and/or any modified version) in any way you find useful,
* provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
*/



namespace VoltageSweepRunSequence
{
    class Program
    {
        static void Main(string[] args)
        {
            double[] voltageList = { 0, .5, 1, 1.5, 2, 2.5, 3 }; // Switch between 0V to 3V in .5V increments
            string outputSource = "P6V";                          // Values can be: P6V , P25V, or N25V

            double[] outputCurrent = new double[voltageList.Length];
            double[] outputVoltage = new double[voltageList.Length];

            SequenceModel seq = new SequenceModel();
            seq.Load("E3631_PowerSupply_VoltageSweep.iseq");
            seq.SetInstrumentAddresses("To Be Filled");

            object[] ret;

            for (int i = 0; i <= voltageList.Length; i++)
            {

                if (i == voltageList.Length)
                {
                    //If we are past the last voltage point then turn off the source
                    ret = seq.Play(0, outputSource, "0");
                }
                else
                {
                    ret = seq.Play(voltageList[i], outputSource, "1");
                    outputCurrent[i] = (double)(ret[0]);
                    outputVoltage[i] = (double)(ret[1]);
                    Console.WriteLine("Voltage Level(V): " + outputVoltage[i] + " consumed " + outputCurrent[i] + " (A)");
                }

            }

            //Hang Console
            Console.WriteLine("\nPress any key to exit");
            Console.ReadLine();

        }
    }
}
