﻿/* 
* This example uses the SCPI.NET driver to control an Agilent E3631A Power Supply.
*
* Description
* Performs a voltage sweep and measures the current drawn at each voltage point. This example sweeps
* the 6V Source (P6V) 0V to 3V in .5V intervals.  Each voltage level is held for 2 seconds before switching to 
* next.  
* 
* Instructions for Running:
* 1. Update the instrument address in the "To Be Filled" connect statement.
* 2. Switch the outputSource variable to the selected source.
*      P6V  - Refers to the 6V Source
*      P25V - Refers to positive 25V Source
*      N25V - Referes to negative 25V Source
* 3. Adjust the VoltageList array with voltage values within the selected source's range.  For example, the P6V 
*    is limited to 6V while the N25V source accepts negative voltage values greater than or equal to -25V.  
* 4. Adjust the voltageInterval duration variable, in milliseconds, to hold the voltage level before switching to the next level.
* 5. For RS-232 connections only, uncomment the "SYSTem:Remote" command below.
* 6. Run this program.
*
* Instructions for compiling.
* This example calls the SCPI.NET E3631A driver that is needed as a reference.  This file is downloaded when 
* Command Expert installs the Agilent E3631A command set.  See Command Expert's Visual Studio help for additional 
* information on file locations.   
* 
* Viewing the Data
* This console application lacks a graphing component for simplicity.  Instead, each voltage point measures the current 
* drawn.  This example prints these values out.  
*    
* Requirements:
* This example was written for the Agilent E3631A Triple Output DC Power Supply, and was tested with firmware version 1.1-5.0-1.0. 
*
* You have a royalty-free right to use, modify, reproduce and distribute 
* this example program (and/or any modified version) in any way you find useful,
* provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
*/
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Agilent.CommandExpert.ScpiNet.AgE3631_2_1;

namespace VoltageSweepScpiDotNet
{
    class Program
    {
        static void Main(string[] args)
        {
            //Adjustable Example Variables
            double [] voltageList = { 0, .5, 1, 1.5, 2, 2.5, 3 }; // Switch between 0V to 3V in .5V increments
            int voltageInterval = 2000;                           // 2 Seconds for each voltage level
            string outputSource = "P6V";                          // Values can be: P6V , P25V, or N25V

            //Connect to E3631A
            AgE3631 E3631 = new AgE3631("To Be Filled");

            //For RS-232 connections only, uncomment the next line
            //E3631.SCPI.SYSTem.REMote.Command();

            double[] outputCurrent = new double[voltageList.Length];
            double[] outputVoltage = new double[voltageList.Length];

            //Cycle thru each voltage level and measure the current drawn
            for (int i = 0; i < voltageList.Length; i++)
            {
                E3631.SCPI.OUTPut.STATe.Command(true);
                E3631.SCPI.APPLy.Command(outputSource, voltageList[i], null);

                //Wait 2 seconds until the PSU outputs next voltage level
                System.Threading.Thread.Sleep(voltageInterval);

                E3631.SCPI.MEASure.CURRent.DC.Query(outputSource, out outputCurrent[i]);
                E3631.SCPI.MEASure.VOLTage.DC.Query(outputSource, out outputVoltage[i]);
                Console.WriteLine("Voltage Level(V): "+outputVoltage[i]+" consumed "+outputCurrent[i]+" (A)");

               
            }

            //Turn off PSU Source
            E3631.SCPI.OUTPut.STATe.Command(false);


            //Hang Console
            Console.WriteLine("\nPress any key to exit");
            Console.ReadLine();
        }
    }
}
