/* 
* This example uses the VISA Instrument Library to control an Agilent E3631A Power Supply.
*
* Description
* Performs a voltage sweep and measures the current drawn at each voltage point. This example sweeps
* the 6V Source (P6V) 0V to 3V in .5V intervals.  Each voltage level is held for 2 seconds before switching to 
* next.  
* 
* Instructions for Running:
* 1. Update the instrument address in the "To Be Filled" connect statement.
* 2. Switch the outputSource variable to the selected source.
*      P6V  - Refers to the 6V Source
*      P25V - Refers to positive 25V Source
*      N25V - Referes to negative 25V Source
* 3. Adjust the voltageList array with voltage values within the selected source's range.  For example, the P6V 
*    is limited to 6V while the N25V source accepts negative voltage values greater than or equal to -25V.  Adjust 
     the sizeOfVoltageList variable to cycle thru the wanted voltages in the list.  
* 4. Adjust the voltageInterval duration variable, in milliseconds, to hold the voltage level before switching to the next level.  
* 5. For RS-232 connections only, uncomment the "SYSTem:Remote" command in the code below.
* 6. Run this program.
*
* Instructions for compiling.
* This example calls the VISA instrument control library. This library is installed with the Agilent IO Libraries Suite.
* The default 32 bit include, linker, and visa32.lib file locations have been included in this solution.  Please see the
* IO Library VISA API help document for additional information on compiling Visual C++ VISA applications.  
* 
* Viewing the Data
* This console application lacks a graphing component for simplicity.  Instead, each voltage point measures the current 
* drawn.  This example prints these values out.  
*    
* Requirements:
* This example was written for the Agilent E3631A Triple Output DC Power Supply, and was tested with firmware version 1.1-5.0-1.0. 
*
* You have a royalty-free right to use, modify, reproduce and distribute 
* this example program (and/or any modified version) in any way you find useful,
* provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
*/

#include "stdafx.h"
#include "visa.h"

int _tmain(int argc, _TCHAR* argv[])
{
	ViSession rm;
	viOpenDefaultRM(&rm);
	ViSession E3631;

	//Changeable Example Variables
	double voltageList[] = {0,.5, 1.0,1.5,2,2.5,3};  // Voltage list to sweep thru
	const int sizeVoltageList   = 7;                // How many levels the example should sweep thru
	int voltageInterval = 2000;                    // 2 seconds
    char * outputSource = "P6V";                  // Values can be P6V, P25V, or N25V


	viOpen(rm, "To Be Filled", VI_NULL, VI_NULL, &E3631);

	ViUInt16 io_prot;
	ViUInt16 intfType;
	ViBoolean termDefaultE3631 = VI_FALSE;
	ViString intfName[512];


	if((VI_SUCCESS == viGetAttribute(E3631, VI_ATTR_RSRC_CLASS, intfName)) && (0 == strcmp("SOCKET", (ViString)intfName)))
		termDefaultE3631 = VI_TRUE;
	else if((VI_SUCCESS == viGetAttribute(E3631, VI_ATTR_INTF_TYPE, &intfType)) && (intfType == VI_INTF_ASRL))
	{
		termDefaultE3631 = VI_TRUE;
		//This remote instrument command is needed for RS-232 connections
		viPrintf(E3631, ":SYSTem:REMote\n");
	}

	viSetAttribute(E3631, VI_ATTR_TERMCHAR_EN, termDefaultE3631);

	//Turn on Power Supply
	viPrintf(E3631, ":OUTPut:STATe %@1d\n", 1);

	double outputCurrent[sizeVoltageList];
	double outputVoltage[sizeVoltageList];

	//Cycle thru each voltage level and measure the current drawn
	for(int i = 0; i < sizeVoltageList; i++)
	{
	    viPrintf(E3631, ":APPLy %s,%@3lf\n", outputSource, voltageList[i]);
		
		//Wait 2 Seconds until the PSU outputs next voltage level
		Sleep(voltageInterval);
		
	    viQueryf(E3631, ":MEASure:CURRent:DC? %s\n", "%lf", "P6V", &outputCurrent[i]);
	    viQueryf(E3631, ":MEASure:VOLTage:DC? %s\n", "%lf", "P6V", &outputVoltage[i]);
		printf("Voltage Level(V): %lf consumed %lf (A)\n", outputVoltage[i], outputCurrent[i]);
		
	}

	//Turn off Power Supply
	viPrintf(E3631, ":OUTPut:STATe %@1d\n", 1);

	viClose(E3631);
	viClose(rm);

	//Hang Console
	char hang;
	printf("\nPress any key to exit...");
	scanf("%c",&hang);

	return 0;
}

