﻿/* 
 * Acquires an autoscaled waveform from a selectable channel of an Agilent InfiniiVision 3000 Series oscilloscope.
 *
 * Description
 * This program's IO code was generated by the export C# feature in Command Expert. For simplicity sake, this example 
 * merely grabs the x and y axis waveform data.  It does not graph it.  
 * 
 * Instructions for Running:
 * 1. Update the instrument address in the "To Be Filled" string statement.
 * 2. Manually set the channel number, 1 thru 4, to match the incoming source.  
 * 3. Add an appropriate input source to the 3000 series oscilloscope to the selected channel above.
 * 4. Run this program.
 *
 * Instructions for compiling.
 * This example calls the SCPI.NET InfiniiVision 3000 driver that is needed as a reference.  This file is downloaded when 
 * Command Expert installs InfiniiVision 3000 Series command set.  See Command Expert's Visual Studio help for additional 
 * information for the file location.  This location depends on your operating system.   
 * 
 * Viewing the Data
 * This example lacks a graphing component for the sack of simplicity. The waveform data is returned in the BYTE format to 
 * increase efficiency across the bus.  The conversion needed uses y-axis preamble information.  The x-axis uses a different
 * set of preamble information. Please see the code below for the conversion information.  
 *    
 * Requirements:
 * This example was written for oscilloscopes in the Agilent InfiniiVision 3000 Series. This was tested with firmware version 01.10.20111042700.
 *
 * You have a royalty-free right to use, modify, reproduce and distribute 
 * this example program (and/or any modified version) in any way you find useful,
 * provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Agilent.CommandExpert.ScpiNet.AgInfiniiVision3000X_01_20;

namespace WaveformScpiDotNet
{
    class Program
    {
        static void Main(string[] args)
        {
            
            //Select Input Channel Source (1-4)
            string channel = "CHANNEL1";
            double xincrement,xorigin, yincrement, yorigin; int yreference;
            const int waveformSize = 1000;
            byte[] waveformBYTEFormatData = new byte[waveformSize];

            
            //Fill in VISA address for 3000 InfiniiVision Scope
            AgInfiniiVision3000X infiniivision = new AgInfiniiVision3000X("To Be Filled");
            Console.WriteLine("Please wait 10 seconds for the waveform to be captured.");
            infiniivision.Transport.DefaultTimeout.Set(10000);
            infiniivision.SCPI.RST.Command();
            infiniivision.SCPI.CLS.Command();
            infiniivision.SCPI.AUToscale.Command(null, null, null, null, null);
            infiniivision.SCPI.DIGitize.Command(null, null, null, null, null);

            // Send 1000 points to represent the waveform.
            infiniivision.SCPI.WAVeform.POINts.CommandPointsMode("NORMal");
            infiniivision.SCPI.WAVeform.POINts.CommandPoints(waveformSize);
            infiniivision.SCPI.WAVeform.SOURce.Command(channel);
            infiniivision.SCPI.WAVeform.FORMat.Command("BYTE");
            infiniivision.SCPI.WAVeform.DATA.QueryBYTE(out waveformBYTEFormatData);
         
            infiniivision.SCPI.WAVeform.XINCrement.Query(out xincrement);
            infiniivision.SCPI.WAVeform.XORigin.Query(out xorigin);
            // Y-axis preamble information converts the BYTE format to actual voltage values.   
            infiniivision.SCPI.WAVeform.YINCrement.Query(out yincrement);
            infiniivision.SCPI.WAVeform.YORigin.Query(out yorigin);
            infiniivision.SCPI.WAVeform.YREFerence.Query(out yreference);

            //Generate Y-Axis Voltage Array from BYTE format
            double [] yAxisVoltage = new double[waveformSize];

            for(int i = 0; i < waveformBYTEFormatData.Length;i++)
            {
                yAxisVoltage[i] = ((double)waveformBYTEFormatData[i] - yreference) * yincrement + yorigin;
            }


            //Generate X-Axis Time Array in Seconds
            double [] xAxisTime = new double[waveformSize];
            
            xAxisTime[0] = xorigin;
            for (int i = 1; i < waveformBYTEFormatData.Length; i++)
            {
                xAxisTime[i] = xAxisTime[i-1] + xincrement;
            }

            Console.WriteLine("\nApplication has created two arrays to plot \nthe waveform if a graphing package was availible.\nFor example: plot(xAxisTime,yAxisVoltage)\n\n---Press any key to exit.---");
            
            Console.ReadLine();

        }


    }
}
