/* 
 * This example uses the VISA Library to control an Agilent InfiniiVision 3000 Series Oscilloscope
 *
 * Description
 * Acquires an autoscaled waveform from a selectable channel of an Agilent InfiniiVision 3000 Series Oscilloscope.
 * 
 * Instructions for Running:
 * 1. Update the VISA instrument address in the "To Be Filled" string statement.
 * 2. Manually set the channelsource variable, 1 thru 4, to match the incoming source.  
 * 3. Add an appropriate input source to the 3000 series oscilloscope to the selected channel above.
 * 4. Run this program.
 *
 * Instructions for compiling.
 * This example calls the Agilent VISA library (visa32.lib) that is needed as a reference with visa.h.  Please see the IO Library Readme 
 * for file locations.  Commom paths have been added to this project.  
 * 
 * Viewing the Data
 * This example lacks a graphing component for the sack of simplicity. The waveform data is returned in the BYTE format to 
 * increase efficiency across the bus.  The conversion needed uses y-axis preamble information.  The x-axis uses a different
 * set of preamble information. Please see the code below for the conversion information. The example collects up to 1000 data points
 * to represent the waveform.  The scope may return fewer data points.  
 *    
 * Requirements:
 * This example was written for oscilloscopes in the Agilent InfiniiVision 3000 Series. This was tested with firmware version 01.10.20111042700.
 *
 * You have a royalty-free right to use, modify, reproduce and distribute 
 * this example program (and/or any modified version) in any way you find useful,
 * provided you agree that Agilent Technologies has no warranty, obligations, or liability for any example programs.
 */

#include "stdafx.h"
#include "visa.h"

int _tmain(int argc, _TCHAR* argv[])
{
	ViSession rm;
	viOpenDefaultRM(&rm);
	ViSession infiniivision;
	viOpen(rm, "To Be Filled", VI_NULL, VI_NULL, &infiniivision);
	printf("Please wait 10 seconds for the waveform to be captured.\n");

	//Replace CHANNELX with your incoming source.
	char * channel = "CHANNEL1";

	const long data_points = 1000;
	long pointsCollected = 1000;
	long yreference = 0;
	double yincrement = 0.0;
	double yorigin = 0.0;
	double xincrement = 0.0;
	double xorigin = 0.0;
    unsigned char data[data_points];

	//Set instrument timeout to 10 seconds
	viSetAttribute(infiniivision,VI_ATTR_TMO_VALUE,10000);
	viPrintf(infiniivision, "*RST\n");
	viPrintf(infiniivision, "*CLS\n");
	viPrintf(infiniivision, ":AUToscale\n");
	viPrintf(infiniivision, ":DIGitize\n");
	// Send 1000 points to represent the waveform.
	viPrintf(infiniivision, ":WAVeform:POINts %s\n", "NORMal");
	//By default represent the waveform using 1000 data points
	viPrintf(infiniivision, ":WAVeform:POINts %@1d\n", data_points);
	viPrintf(infiniivision, ":WAVeform:SOURce %s\n", channel);
	
	viPrintf(infiniivision, ":WAVeform:FORMat %s\n", "BYTE");
	viQueryf(infiniivision, ":WAVeform:DATA?\n", "%#b",&pointsCollected, &data);
	// X-Axis preamble information is used create the time based x axis values.  
	viQueryf(infiniivision, ":WAVeform:XINCrement?\n", "%lf", &xincrement);
	viQueryf(infiniivision, ":WAVeform:XORigin?\n", "%lf", &xorigin);
	// Y-axis preamble information converts the BYTE format to actual voltage values.  
	viQueryf(infiniivision, ":WAVeform:YINCrement?\n", "%lf", &yincrement);
	viQueryf(infiniivision, ":WAVeform:YORigin?\n", "%lf", &yorigin);
	viQueryf(infiniivision, ":WAVeform:YREFerence?\n", "%d", &yreference);
	viClose(infiniivision);
	viClose(rm);

	//Convert yAxis voltage data
	double yAxisVoltageData[data_points];
	for(int i = 0; i < (pointsCollected-1);i++)
	{
		yAxisVoltageData[i] = ((int)data[i] - yreference) * yincrement + yorigin;
	}


	//Convert xAxis Time Data
	double xAxisTimeData[data_points];
	xAxisTimeData[0] = xorigin;
	for(int i = 1; i < (pointsCollected-1);i++)
	{
		xAxisTimeData[i] = xAxisTimeData[i-1] + xincrement;
	}

	/* At this point one could plot(xAxisTimeData,yAxisVoltageData) */
	printf("....\nExample collected data into two arrays, one per axis.\nPlease see documentation in code example for usage.  Press enter to exit\n....\n");
	getch();
	
	return 0;
}

